@@ -1,4 +1,4 @@
-from maleo.schemas.resource import Resource, ResourceIdentifier
+from nexo.schemas.resource import Resource, ResourceIdentifier
 
 CLIENT_RESOURCE = Resource(
     identifiers=[ResourceIdentifier(key="client", name="Client", slug="clients")],
