@@ -1,4 +1,4 @@
-from maleo.schemas.resource import Resource, ResourceIdentifier
+from nexo.schemas.resource import Resource, ResourceIdentifier
 
 PARAMETER_RESOURCE = Resource(
     identifiers=[
