@@ -1,6 +1,6 @@
 from enum import StrEnum
 from typing import TypeVar
-from maleo.types.string import ListOfStrs
+from nexo.types.string import ListOfStrs
 
 
 class Granularity(StrEnum):
