@@ -1,6 +1,15 @@
 from enum import StrEnum
 from typing import TypeVar
-from maleo.types.string import ListOfStrs
+from nexo.types.string import ListOfStrs
+
+
+class Granularity(StrEnum):
+    STANDARD = "standard"
+    FULL = "full"
+
+    @classmethod
+    def choices(cls) -> ListOfStrs:
+        return [e.value for e in cls]
 
 
 class IdentifierType(StrEnum):
