@@ -1,36 +1,32 @@
 from pydantic import BaseModel, Field
 from typing import Annotated, Generic, Literal, Self, TypeVar, overload
 from uuid import UUID
-from maleo.enums.status import (
-    DataStatus,
+from nexo.enums.status import (
     ListOfDataStatuses,
-    SimpleDataStatusMixin,
     FULL_DATA_STATUSES,
 )
-from maleo.schemas.mixins.filter import ListOfDateFilters, convert as convert_filter
-from maleo.schemas.mixins.identity import (
+from nexo.schemas.mixins.filter import ListOfDateFilters, convert as convert_filter
+from nexo.schemas.mixins.identity import (
     IdentifierMixin,
-    DataIdentifier,
     UUIDOrganizationId,
     UUIDOrganizationIds,
     Ids,
     UUIDs,
     Names,
 )
-from maleo.schemas.mixins.sort import ListOfSortColumns, convert as convert_sort
-from maleo.schemas.mixins.timestamp import DataTimestamp
-from maleo.schemas.operation.enums import ResourceOperationStatusUpdateType
-from maleo.schemas.pagination import Limit
-from maleo.schemas.parameter import (
+from nexo.schemas.mixins.sort import ListOfSortColumns, convert as convert_sort
+from nexo.schemas.operation.enums import ResourceOperationStatusUpdateType
+from nexo.schemas.pagination import Limit
+from nexo.schemas.parameter import (
     ReadSingleParameter as BaseReadSingleParameter,
     ReadPaginatedMultipleParameter,
     StatusUpdateParameter as BaseStatusUpdateParameter,
     DeleteSingleParameter as BaseDeleteSingleParameter,
 )
-from maleo.types.dict import StrToAnyDict
-from maleo.types.integer import OptListOfInts
-from maleo.types.string import OptListOfStrs, OptStr
-from maleo.types.uuid import OptListOfUUIDs
+from nexo.types.dict import StrToAnyDict
+from nexo.types.integer import OptListOfInts
+from nexo.types.string import OptListOfStrs, OptStr
+from nexo.types.uuid import OptListOfUUIDs
 from ..enums.client import IdentifierType
 from ..mixins.client import Name, ClientIdentifier
 from ..types.client import IdentifierValueType
@@ -284,13 +280,3 @@ class DeleteSingleParameter(BaseDeleteSingleParameter[ClientIdentifier]):
         return cls(
             identifier=ClientIdentifier(type=identifier_type, value=identifier_value)
         )
-
-
-class ClientSchema(
-    Name,
-    UUIDOrganizationId[UUID],
-    SimpleDataStatusMixin[DataStatus],
-    DataTimestamp,
-    DataIdentifier,
-):
-    pass
