@@ -126,6 +126,7 @@ class StandardRuleSchema(
     pass
 
 
+OptStandardRuleSchema = StandardRuleSchema | None
 ListOfStandardRuleSchemas = list[StandardRuleSchema]
 
 
@@ -182,9 +183,14 @@ class BaseExaminationSchema(ParameterSchemaMixin[StandardParameterSchema]):
 
 
 class ExaminationSchema(
-    RuleSchemaMixin[StandardRuleSchema | None],
+    RuleSchemaMixin[OptStandardRuleSchema],
     ExaminationStatus[OptExaminationStatus],
     BaseExaminationSchema,
+    UUIDOrganizationId[UUID],
+    UUIDUserId[UUID],
+    SimpleDataStatusMixin[DataStatus],
+    LifecycleTimestamp,
+    DataIdentifier,
 ):
     def classify(self, age: float, rules: list[StandardRuleSchema]):
         parameter = self.parameter
