@@ -1,30 +1,30 @@
 from pydantic import BaseModel, Field, model_validator
 from typing import Annotated, Generic, Literal, Self, TypeVar, overload
 from uuid import UUID
-from maleo.enums.status import (
+from nexo.enums.status import (
     ListOfDataStatuses,
     FULL_DATA_STATUSES,
 )
-from maleo.schemas.mixins.filter import convert as convert_filter
-from maleo.schemas.mixins.identity import (
+from nexo.schemas.mixins.filter import convert as convert_filter
+from nexo.schemas.mixins.identity import (
     IdentifierMixin,
     Ids,
     UUIDs,
     Names,
 )
-from maleo.schemas.mixins.sort import convert as convert_sort
-from maleo.schemas.operation.enums import ResourceOperationStatusUpdateType
-from maleo.schemas.parameter import (
+from nexo.schemas.mixins.sort import convert as convert_sort
+from nexo.schemas.operation.enums import ResourceOperationStatusUpdateType
+from nexo.schemas.parameter import (
     ReadSingleParameter as BaseReadSingleParameter,
     ReadPaginatedMultipleParameter,
     StatusUpdateParameter as BaseStatusUpdateParameter,
     DeleteSingleParameter as BaseDeleteSingleParameter,
 )
-from maleo.types.boolean import OptBool
-from maleo.types.dict import StrToAnyDict
-from maleo.types.integer import OptListOfInts
-from maleo.types.string import OptStr, OptListOfStrs
-from maleo.types.uuid import OptListOfUUIDs
+from nexo.types.boolean import OptBool
+from nexo.types.dict import StrToAnyDict
+from nexo.types.integer import OptListOfInts
+from nexo.types.string import OptStr, OptListOfStrs
+from nexo.types.uuid import OptListOfUUIDs
 from ..enums.parameter import (
     IdentifierType,
     ParameterGroup,
